@@ -1,6 +1,6 @@
 #!/usr/bin/env node
+import { spawn } from 'node:child_process';
 import fsPromises from 'node:fs/promises';
-
 import type { EphemeralServerSpec } from './cli/adhoc-server.js';
 import { printCallHelp, handleCall as runHandleCall } from './cli/call-command.js';
 import { buildGlobalContext } from './cli/cli-factory.js';
@@ -21,10 +21,12 @@ import { consumeOutputFormat } from './cli/output-format.js';
 import { DEBUG_HANG, dumpActiveHandles, terminateChildProcesses } from './cli/runtime-debug.js';
 import { boldText, dimText, extraDimText, supportsAnsiColor } from './cli/terminal.js';
 import { resolveConfigPath } from './config.js';
+import type { ServerDefinition } from './config-schema.js';
 import { DaemonClient } from './daemon/client.js';
 import { createKeepAliveRuntime } from './daemon/runtime-wrapper.js';
 import { analyzeConnectionError } from './error-classifier.js';
 import { isKeepAliveServer } from './lifecycle.js';
+import { clearOAuthCaches } from './oauth-persistence.js';
 import { createRuntime, MCPORTER_VERSION } from './runtime.js';
 
 export { parseCallArguments } from './cli/call-arguments.js';
@@ -80,14 +82,17 @@ export async function runCli(argv: string[]): Promise<void> {
   const configPath = runtimeOptions.configPath ?? globalFlags['--config'];
   const configResolution = resolveConfigPath(globalFlags['--config'], rootOverride ?? process.cwd());
   const configPathResolved = configPath ?? configResolution.path;
+  // Only pass configPath to runtime options if it was explicitly provided (via --config flag or env var).
+  // If not explicit, let loadConfigLayers handle the default resolution to avoid ENOENT on missing config.
   const runtimeOptionsWithPath = {
     ...runtimeOptions,
-    configPath: runtimeOptions.configPath ?? configPathResolved,
+    configPath: configResolution.explicit ? configPathResolved : runtimeOptions.configPath,
   };
 
   if (command === 'daemon') {
     await handleDaemonCli(args, {
       configPath: configPathResolved,
+      configExplicit: configResolution.explicit,
       rootDir: rootOverride,
     });
     return;
@@ -122,7 +127,13 @@ export async function runCli(argv: string[]): Promise<void> {
       .map((entry) => entry.name)
   );
   const daemonClient =
-    keepAliveServers.size > 0 ? new DaemonClient({ configPath: configResolution.path, rootDir: rootOverride }) : null;
+    keepAliveServers.size > 0
+      ? new DaemonClient({
+          configPath: configResolution.path,
+          configExplicit: configResolution.explicit,
+          rootDir: rootOverride,
+        })
+      : null;
   const runtime = createKeepAliveRuntime(baseRuntime, { daemonClient, keepAliveServers });
 
   const inference = inferCommandRouting(command, args, runtime.getDefinitions());
@@ -462,14 +473,15 @@ export async function handleAuth(runtime: Awaited<ReturnType<typeof createRuntim
 
   const definition = runtime.getDefinition(target);
   if (shouldReset) {
-    const tokenDir = definition.tokenCacheDir;
-    if (tokenDir) {
-      // Drop the cached credentials so the next auth run starts cleanly.
-      await fsPromises.rm(tokenDir, { recursive: true, force: true });
-      logInfo(`Cleared cached credentials for '${target}' at ${tokenDir}`);
-    } else {
-      logWarn(`Server '${target}' does not expose a token cache path.`);
-    }
+    await clearOAuthCaches(definition);
+    logInfo(`Cleared cached credentials for '${target}'.`);
+  }
+
+  if (definition.command.kind === 'stdio' && definition.oauthCommand) {
+    logInfo(`Starting auth helper for '${target}' (stdio). Leave this running until the browser flow completes.`);
+    await runStdioAuth(definition);
+    logInfo(`Auth helper for '${target}' finished. You can now call tools.`);
+    return;
   }
 
   // Kick off the interactive OAuth flow without blocking list output. We retry once if the
@@ -510,6 +522,28 @@ async function invokeAuthCommand(runtimeOptions: Parameters<typeof createRuntime
   }
 }
 
+async function runStdioAuth(definition: ServerDefinition): Promise<void> {
+  const authArgs = [...(definition.command.kind === 'stdio' ? (definition.command.args ?? []) : [])];
+  if (definition.oauthCommand) {
+    authArgs.push(...definition.oauthCommand.args);
+  }
+  return new Promise((resolve, reject) => {
+    const child = spawn(definition.command.kind === 'stdio' ? definition.command.command : '', authArgs, {
+      stdio: 'inherit',
+      cwd: definition.command.kind === 'stdio' ? definition.command.cwd : process.cwd(),
+      env: process.env,
+    });
+    child.on('error', reject);
+    child.on('exit', (code) => {
+      if (code === 0) {
+        resolve();
+      } else {
+        reject(new Error(`Auth helper exited with code ${code ?? 'null'}`));
+      }
+    });
+  });
+}
+
 function shouldRetryAuthError(error: unknown): boolean {
   return analyzeConnectionError(error).kind === 'auth';
 }
