@@ -1,5 +1,5 @@
-import fs from 'node:fs/promises';
 import { loadServerDefinitions } from '../../config.js';
+import { clearOAuthCaches } from '../../oauth-persistence.js';
 import { CliUsageError } from '../errors.js';
 import { resolveServerDefinition } from './shared.js';
 import type { ConfigCliOptions } from './types.js';
@@ -18,10 +18,6 @@ export async function handleLogoutCommand(options: ConfigCliOptions, args: strin
   }
   const servers = await loadServerDefinitions(options.loadOptions);
   const target = resolveServerDefinition(name, servers);
-  if (!target.tokenCacheDir) {
-    console.log(`Server '${name}' does not expose a token cache directory.`);
-    return;
-  }
-  await fs.rm(target.tokenCacheDir, { recursive: true, force: true });
-  console.log(`Cleared cached credentials for '${target.name}' (${target.tokenCacheDir})`);
+  await clearOAuthCaches(target);
+  console.log(`Cleared cached credentials for '${target.name}'`);
 }
