@@ -1,5 +1,3 @@
-import os from 'node:os';
-import path from 'node:path';
 import type { ServerDefinition } from './config.js';
 import { analyzeConnectionError } from './error-classifier.js';
 import type { Logger } from './logging.js';
@@ -15,12 +13,10 @@ export function maybeEnableOAuth(definition: ServerDefinition, logger: Logger):
   if (!isAdHocSource) {
     return undefined;
   }
-  const tokenCacheDir = definition.tokenCacheDir ?? path.join(os.homedir(), '.mcporter', definition.name);
   logger.info(`Detected OAuth requirement for '${definition.name}'. Launching browser flow...`);
   return {
     ...definition,
     auth: 'oauth',
-    tokenCacheDir,
   };
 }
 
