@@ -1,6 +1,3 @@
-import fs from 'node:fs/promises';
-import os from 'node:os';
-import path from 'node:path';
 import { Client } from '@modelcontextprotocol/sdk/client/index.js';
 import { SSEClientTransport } from '@modelcontextprotocol/sdk/client/sse.js';
 import { StdioClientTransport } from '@modelcontextprotocol/sdk/client/stdio.js';
@@ -10,6 +7,7 @@ import type { ServerDefinition } from '../config.js';
 import { resolveEnvValue, withEnvOverrides } from '../env.js';
 import type { Logger } from '../logging.js';
 import { createOAuthSession, type OAuthSession } from '../oauth.js';
+import { readCachedAccessToken } from '../oauth-persistence.js';
 import { materializeHeaders } from '../runtime-header-utils.js';
 import { isUnauthorizedError, maybeEnableOAuth } from '../runtime-oauth-support.js';
 import { closeTransportAndWait } from '../runtime-process-utils.js';
@@ -23,25 +21,6 @@ function attachStdioTraceLogging(_transport: StdioClientTransport, _label?: stri
   // so runtime callers can opt-in without sprinkling conditional checks everywhere.
 }
 
-async function loadCachedAccessToken(definition: ServerDefinition): Promise<string | undefined> {
-  const tokenDir = definition.tokenCacheDir ?? path.join(os.homedir(), '.mcporter', definition.name);
-  const tokensPath = path.join(tokenDir, 'tokens.json');
-  try {
-    const buffer = await fs.readFile(tokensPath, 'utf8');
-    const parsed = JSON.parse(buffer);
-    const token = parsed?.access_token;
-    if (typeof token === 'string' && token.trim().length > 0) {
-      return token;
-    }
-    return undefined;
-  } catch (error) {
-    if ((error as NodeJS.ErrnoException).code === 'ENOENT') {
-      return undefined;
-    }
-    throw error;
-  }
-}
-
 export interface ClientContext {
   readonly client: Client;
   readonly transport: Transport & { close(): Promise<void> };
@@ -67,7 +46,7 @@ export async function createClientContext(
 
   if (options.allowCachedAuth && activeDefinition.auth === 'oauth' && activeDefinition.command.kind === 'http') {
     try {
-      const cached = await loadCachedAccessToken(activeDefinition);
+      const cached = await readCachedAccessToken(activeDefinition, logger);
       if (cached) {
         const existingHeaders = activeDefinition.command.headers ?? {};
         if (!('Authorization' in existingHeaders)) {
